//Source file: CallRelatedSendInfoAndCollect.java
//Date: June 2006
//User Interaction for 3GPP TS 29.198-05 V6.5.0

package org.csapi.jr.se.ui;

/**
 *  A call related 'Send Info And Collect' activity object.
 */
public interface CallRelatedSendInfoAndCollect extends org.csapi.jr.se.Activity {

	/**
	 * Returns a reference to the UICall responsible for creation of the
	 * CallRelatedSendInfoAndCollect.
	 *
	 * @return  The UICall responsible for creation of the CallRelatedSendInfoAndCollect
	 */
	org.csapi.jr.se.ui.UICall getUICall();


	/**
	 * Adds a CallRelatedSendInfoAndCollectListener which is interested in events
	 * generated by the CallRelatedSendInfoAndCollect.
	 *
	 * @param  callRelatedSendInfoAndCollectListener  Reference to the
	 *      CallRelatedSendInfoAndCollectListener which is to be added as a
	 *      listener.
	 */
	void addCallRelatedSendInfoAndCollectListener(org.csapi.jr.se.ui.CallRelatedSendInfoAndCollectListener callRelatedSendInfoAndCollectListener);


	/**
	 * Removes a CallRelatedSendInfoAndCollectListener which is no longer
	 * interested events generated by the CallRelatedSendInfoAndCollect.
	 *
	 * @param  callRelatedSendInfoAndCollectListener  Reference to the
	 *      CallRelatedSendInfoAndCollectListener which is to be removed as a
	 *      listener.
	 */
	void removeCallRelatedSendInfoAndCollectListener(org.csapi.jr.se.ui.CallRelatedSendInfoAndCollectListener callRelatedSendInfoAndCollectListener);


	/**
	 * This asynchronous method plays an announcement or sends other information
	 * to the user and collects some information from the user. The announcement
	 * usually prompts for a number of characters (for example, these are digits
	 * or text strings such as "YES" if the user's terminal device is a phone).
	 *
	 * @param  info   Specifies the ID of the information to send to the user.<br> 
         *      This information can be:<br>
	 *      - an infoID, identifying pre-defined information to be send (announcement
	 *      and/or text);<br> 
         *      - a string, defining the text to be sent;<br> 
         *      - a URL, identifying pre-defined information or data to be sent to or 
	 *      downloaded into the terminal<br>
	 * @param  language  Specifies the language of the information to be send to the user
	 * @param  variableInfo  Defines the  variable part of the information to send to the user
	 * @param  criteria  Specifies  additional properties for the collection of 
	 *      information, such as the maximum and minimum number of characters, end 
	 *	character, first character timeout and inter-character timeout.
	 * @param  responseRequested  Specifies if a response is required from the call 
	 *	user interaction service, and any action the service should take. For 
	 *	this case it can especially be used to indicate, for example, the final request
	 * @exception  org.csapi.jr.se.PlatformException  if the implementation detected 
	 *	an internal (for example, communication) error
	 * @exception  java.lang.IllegalStateException   if the JR API object is not in 
	 *	a state suitable for the invocation
         * @exception  org.csapi.jr.se.CommonException  defines the structure  of the exception 
	 *	class which is applicable to all methods
	 * @exception  org.csapi.jr.se.InvalidNetworkStateException  if the sequence of method 
	 *	calls is allowed by the gateway but the underlying protocol can not support it
	 * @exception  org.csapi.jr.se.ui.IllegalIdException  if an information id specified 
	 * 	is invalid
	 * @exception  org.csapi.jr.se.InvalidCriteriaException  if invalid criteria specified
	 * @exception  org.csapi.jr.se.ui.IllegalRangeException  if the values for minimum and 
	 *	maximum collection length are out of range
	 * @exception  org.csapi.jr.se.ui.InvalidCollectionCriteriaException  if invalid
	 *      collection criteria specified
	 */
	void sendInfoAndCollectReq(org.csapi.jr.se.ui.UIInfo info,
		java.lang.String language,
		org.csapi.jr.se.ui.UIVariableInfo[] variableInfo,
		org.csapi.jr.se.ui.UICollectCriteria criteria,
		int responseRequested)
		throws org.csapi.jr.se.PlatformException,
		java.lang.IllegalStateException,
		org.csapi.jr.se.CommonException,
		org.csapi.jr.se.InvalidNetworkStateException,
		org.csapi.jr.se.ui.IllegalIdException,
		org.csapi.jr.se.InvalidCriteriaException,
		org.csapi.jr.se.ui.IllegalRangeException,
		org.csapi.jr.se.ui.InvalidCollectionCriteriaException;


	/**
	 *  This asynchronous method aborts a user interaction operation, for example,
	 *  a sendInfoReq(), from the specified call leg. The call and call leg are
	 *  otherwise unaffected. The user interaction call service interrupts the
	 *  current action on the specified leg.
	 *
	 * @exception  org.csapi.jr.se.PlatformException if the implementation
	 *      detected an internal (for example, communication) error
	 * @exception  java.lang.IllegalStateException  if the JR API object is not 
	 *	in a state suitable for the invocation
         * @exception  org.csapi.jr.se.CommonException  defines the structure  of the exception 
	 *	class which is applicable to all methods
	 */
	void abortActionReq()
	 	throws org.csapi.jr.se.PlatformException,
		java.lang.IllegalStateException,
		org.csapi.jr.se.CommonException;
}
