//Source file: CallRelatedSendInfoListener.java
//Date: June 2006
//User Interaction for 3GPP TS 29.198-05 V6.5.0

package org.csapi.jr.se.ui;

/**
 * This interface is to be implemented for receiving events emitted by the
 * call related 'Send Info' activity object.
 */
public interface CallRelatedSendInfoListener extends java.util.EventListener {

	/**
	 * Invoked when the request to send information was successful.
	 *
	 * @param  sendInfoResEvent  Reference to a SendInfoResEvent event emitted from
	 *      the activity object.
	 */
	void onSendInfoResEvent(org.csapi.jr.se.ui.SendInfoResEvent sendInfoResEvent);


	/**
	 * Invoked when the request to send information was unsuccessful.
	 *
	 * @param  sendInfoErrEvent  Reference to a SendInfoErrEvent event emitted from
	 *      the activity object.
	 */
	void onSendInfoErrEvent(org.csapi.jr.se.ui.SendInfoErrEvent sendInfoErrEvent);


	/**
	 * Invoked when the request to abort a user interaction operation on a
	 * call/call leg was successful.
	 *
	 * @param  abortActionResEvent  Reference to an AbortActionResEvent event emitted
	 *      from the activity object.
	 */
	void onAbortActionResEvent(org.csapi.jr.se.ui.AbortActionResEvent abortActionResEvent);


	/**
	 * Invoked when the request to abort a user interaction operation on a
	 * call/call leg resulted in an error.
	 *
	 * @param  abortActionErrEvent  Reference to an AbortActionErrEvent event emitted
	 *      from the activity object.
	 */
	void onAbortActionErrEvent(org.csapi.jr.se.ui.AbortActionErrEvent abortActionErrEvent);

}
