//Source file: UICollectMode.java
//Date: June 2006
//User Interaction for 3GPP TS 29.198-05 V6.5.0

package org.csapi.jr.se.ui;

/**
 * Defines the type of collection.
 *
 */
public final class UICollectMode implements java.io.Serializable {

    private int _value;
    private static int _size = 3;
    private static UICollectMode[] _array = new UICollectMode[_size];

    /**
     * Private constructor used internally to construct static objects 
     */
    private UICollectMode(int value) {
        _value = value;
        _array[_value] = this;
    }

    /**
     * Collect DTMF digits only
     */
    public static final int _UI_COLLECT_MODE_DTMF =  0;

    /**
     * Collect DTMF digits only
     */
    public static final UICollectMode UI_COLLECT_MODE_DTMF = new UICollectMode(_UI_COLLECT_MODE_DTMF);

    /**
     * Collect Voice recognized data
     */
    public static final int _UI_COLLECT_MODE_VOICE =  1;

    /**
     * Collect Voice recognized data
     */
    public static final UICollectMode UI_COLLECT_MODE_VOICE = new UICollectMode(_UI_COLLECT_MODE_VOICE);

    /**
     * Collect both DTMF digits and voice recognized data
     */
    public static final int _UI_COLLECT_MODE_DTMFANDVOICE =  2;

    /**
     * Collect both DTMF digits and voice recognized data
     */
    public static final UICollectMode UI_COLLECT_MODE_DTMFANDVOICE = new UICollectMode(_UI_COLLECT_MODE_DTMFANDVOICE);


    /**
     * Method allows class to replace/resolve the object read from the stream before it 
     * is returned to the caller. By implementing this method, a class can directly control
     * the types and instances of its own instances being deserialized.
     *
     * @return the resolved UICollectMode object 
     */
    private Object readResolve() throws java.io.ObjectStreamException {
        return _array[_value];
    }

    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * getValueText method, overrides the getValueText() method in class java.lang.Object
     *
     * @return String  The stringified version of the UICollectMode object
     */
    public String getValueText() {
        switch (_value) {
            case _UI_COLLECT_MODE_DTMF:
                return "UI_COLLECT_MODE_DTMF";
            case _UI_COLLECT_MODE_VOICE:
                return "UI_COLLECT_MODE_VOICE";
            case _UI_COLLECT_MODE_DTMFANDVOICE:
                return "UI_COLLECT_MODE_DTMFANDVOICE";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 2
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static UICollectMode getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException("value [" + value +" ] out of range");
        }
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof UICollectMode)) {
            return false;
        }
        UICollectMode uICollectMode = (UICollectMode) o; 
        if(!(this.getValue() == uICollectMode.getValue())) {
            return false;
        }
        if (this.hashCode() != uICollectMode.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // UICollectMode

