//Source file: UIEventCriteria.java
//Date: June 2006
//User Interaction for 3GPP TS 29.198-05 V6.5.0

package org.csapi.jr.se.ui;

/**
 * Defines the Sequence of Data Elements that specify the additional criteria for receiving a UI notification.
 * 
 */
public final class UIEventCriteria implements java.io.Serializable {

    private org.csapi.jr.se.AddressRange originatingAddress;
    private org.csapi.jr.se.AddressRange destinationAddress;
    private String serviceCode;

    /**
     * Creates a new UIEventCriteria instance.
     */
    public UIEventCriteria () {}

    /**
     * Creates a new UIEventCriteria instance.
     * @param _originatingAddress   Defines the originating address. 
     * @param _destinationAddress   Defines the destination address.
     * @param _serviceCode   Defines a 2-digit code indicating the UI to be triggered. 
The value is operator specific.
     */
    public UIEventCriteria (org.csapi.jr.se.AddressRange _originatingAddress, org.csapi.jr.se.AddressRange _destinationAddress, String _serviceCode) {

        this.originatingAddress = _originatingAddress;
        this.destinationAddress = _destinationAddress;
        this.serviceCode = _serviceCode;
    }

    /**
     * This method returns a originatingAddress.
     * 
     * @return a org.csapi.jr.se.AddressRange value
     */
    public org.csapi.jr.se.AddressRange getOriginatingAddress() {
        return originatingAddress;
    }

    /**
     * This method returns a destinationAddress.
     * 
     * @return a org.csapi.jr.se.AddressRange value
     */
    public org.csapi.jr.se.AddressRange getDestinationAddress() {
        return destinationAddress;
    }

    /**
     * This method returns a serviceCode.
     * 
     * @return a String value
     */
    public String getServiceCode() {
        return serviceCode;
    }


    /**
     * This method sets a originatingAddress.
     */ 
    public void setOriginatingAddress(org.csapi.jr.se.AddressRange originatingAddress) {
        this.originatingAddress = originatingAddress;
    }

    /**
     * This method sets a destinationAddress.
     */ 
    public void setDestinationAddress(org.csapi.jr.se.AddressRange destinationAddress) {
        this.destinationAddress = destinationAddress;
    }

    /**
     * This method sets a serviceCode.
     */ 
    public void setServiceCode(String serviceCode) {
        this.serviceCode = serviceCode;
    }


    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof UIEventCriteria)) {
            return false;
        } 
        UIEventCriteria uIEventCriteria = (UIEventCriteria) o;
        if ((this.originatingAddress != null) && (uIEventCriteria.originatingAddress != null)) {
            if(!(this.originatingAddress.equals(uIEventCriteria.originatingAddress))) {
                return false;
            }
        }
        if ((this.destinationAddress != null) && (uIEventCriteria.destinationAddress != null)) {
            if(!(this.destinationAddress.equals(uIEventCriteria.destinationAddress))) {
                return false;
            }
        }
        if ((this.serviceCode != null) && (uIEventCriteria.serviceCode != null)) {
            if(!(this.serviceCode.equals(uIEventCriteria.serviceCode)))  {
                return false;
            }
        }
        if (this.hashCode() != o.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // UIEventCriteria

