//Source file: UIEventInfoDataType.java
//Date: June 2006
//User Interaction for 3GPP TS 29.198-05 V6.5.0

package org.csapi.jr.se.ui;

/**
 * Defines the type of the dataString parameter in the method userInteractionEventNotify.
 *
 */
public final class UIEventInfoDataType implements java.io.Serializable {

    private int _value;
    private static int _size = 4;
    private static UIEventInfoDataType[] _array = new UIEventInfoDataType[_size];

    /**
     * Private constructor used internally to construct static objects 
     */
    private UIEventInfoDataType(int value) {
        _value = value;
        _array[_value] = this;
    }

    /**
     * Undefined (for example binary data)
     */
    public static final int _UI_EVENT_DATA_TYPE_UNDEFINED =  0;

    /**
     * Undefined (for example binary data)
     */
    public static final UIEventInfoDataType UI_EVENT_DATA_TYPE_UNDEFINED = new UIEventInfoDataType(_UI_EVENT_DATA_TYPE_UNDEFINED);

    /**
     * Unspecified data
     */
    public static final int _UI_EVENT_DATA_TYPE_UNSPECIFIED =  1;

    /**
     * Unspecified data
     */
    public static final UIEventInfoDataType UI_EVENT_DATA_TYPE_UNSPECIFIED = new UIEventInfoDataType(_UI_EVENT_DATA_TYPE_UNSPECIFIED);

    /**
     * Text
     */
    public static final int _UI_EVENT_DATA_TYPE_TEXT =  2;

    /**
     * Text
     */
    public static final UIEventInfoDataType UI_EVENT_DATA_TYPE_TEXT = new UIEventInfoDataType(_UI_EVENT_DATA_TYPE_TEXT);

    /**
     * USSD data starting with coding scheme
     */
    public static final int _UI_EVENT_DATA_TYPE_USSD_DATA =  3;

    /**
     * USSD data starting with coding scheme
     */
    public static final UIEventInfoDataType UI_EVENT_DATA_TYPE_USSD_DATA = new UIEventInfoDataType(_UI_EVENT_DATA_TYPE_USSD_DATA);


    /**
     * Method allows class to replace/resolve the object read from the stream before it 
     * is returned to the caller. By implementing this method, a class can directly control
     * the types and instances of its own instances being deserialized.
     *
     * @return the resolved UIEventInfoDataType object 
     */
    private Object readResolve() throws java.io.ObjectStreamException {
        return _array[_value];
    }

    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * getValueText method, overrides the getValueText() method in class java.lang.Object
     *
     * @return String  The stringified version of the UIEventInfoDataType object
     */
    public String getValueText() {
        switch (_value) {
            case _UI_EVENT_DATA_TYPE_UNDEFINED:
                return "UI_EVENT_DATA_TYPE_UNDEFINED";
            case _UI_EVENT_DATA_TYPE_UNSPECIFIED:
                return "UI_EVENT_DATA_TYPE_UNSPECIFIED";
            case _UI_EVENT_DATA_TYPE_TEXT:
                return "UI_EVENT_DATA_TYPE_TEXT";
            case _UI_EVENT_DATA_TYPE_USSD_DATA:
                return "UI_EVENT_DATA_TYPE_USSD_DATA";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 3
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static UIEventInfoDataType getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException("value [" + value +" ] out of range");
        }
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof UIEventInfoDataType)) {
            return false;
        }
        UIEventInfoDataType uIEventInfoDataType = (UIEventInfoDataType) o; 
        if(!(this.getValue() == uIEventInfoDataType.getValue())) {
            return false;
        }
        if (this.hashCode() != uIEventInfoDataType.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // UIEventInfoDataType

