//Source file: UIInfoType.java
//Date: June 2006
//User Interaction for 3GPP TS 29.198-05 V6.5.0

package org.csapi.jr.se.ui;

/**
 * Defines the type of the information to be sent to the user.
 *
 */
public final class UIInfoType implements java.io.Serializable {

    private int _value;
    private static int _size = 10;
    private static UIInfoType[] _array = new UIInfoType[_size];

    /**
     * Private constructor used internally to construct static objects 
     */
    private UIInfoType(int value) {
        _value = value;
        _array[_value] = this;
    }

    /**
     * The information to be sent to an end-user consists of an ID.
     */
    public static final int _UI_INFO_ID =  0;

    /**
     * The information to be sent to an end-user consists of an ID.
     */
    public static final UIInfoType UI_INFO_ID = new UIInfoType(_UI_INFO_ID);

    /**
     * The information to be sent to an end-user consists of a data string.
     */
    public static final int _UI_INFO_DATA =  1;

    /**
     * The information to be sent to an end-user consists of a data string.
     */
    public static final UIInfoType UI_INFO_DATA = new UIInfoType(_UI_INFO_DATA);

    /**
     * The information to be sent to an end-user consists of a URL.
     */
    public static final int _UI_INFO_ADDRESS =  2;

    /**
     * The information to be sent to an end-user consists of a URL.
     */
    public static final UIInfoType UI_INFO_ADDRESS = new UIInfoType(_UI_INFO_ADDRESS);

    /**
     * The information to be sent to an end-user consists of a 8 bit binary data set.
     */
    public static final int _UI_INFO_BIN_DATA =  3;

    /**
     * The information to be sent to an end-user consists of a 8 bit binary data set.
     */
    public static final UIInfoType UI_INFO_BIN_DATA = new UIInfoType(_UI_INFO_BIN_DATA);

    /**
     * The information to be sent to an end-user consists of UUEncoded data
     */
    public static final int _UI_INFO_UUENCODED =  4;

    /**
     * The information to be sent to an end-user consists of UUEncoded data
     */
    public static final UIInfoType UI_INFO_UUENCODED = new UIInfoType(_UI_INFO_UUENCODED);

    /**
     * The information to be sent to the end-user consists of MIME encoded data
     */
    public static final int _UI_INFO_MIME =  5;

    /**
     * The information to be sent to the end-user consists of MIME encoded data
     */
    public static final UIInfoType UI_INFO_MIME = new UIInfoType(_UI_INFO_MIME);

    /**
     * The information to be sent to the end-user is .wav waveform data
     */
    public static final int _UI_INFO_WAVE =  6;

    /**
     * The information to be sent to the end-user is .wav waveform data
     */
    public static final UIInfoType UI_INFO_WAVE = new UIInfoType(_UI_INFO_WAVE);

    /**
     * The information to be sent to the end-user is .au audio data
     */
    public static final int _UI_INFO_AU =  7;

    /**
     * The information to be sent to the end-user is .au audio data
     */
    public static final UIInfoType UI_INFO_AU = new UIInfoType(_UI_INFO_AU);

    /**
     * The information to be sent to the end-user is controlled by this VXML
     */
    public static final int _UI_INFO_VXML =  8;

    /**
     * The information to be sent to the end-user is controlled by this VXML
     */
    public static final UIInfoType UI_INFO_VXML = new UIInfoType(_UI_INFO_VXML);

    /**
     * The information to be sent to an end-user is synthesized from text.
     */
    public static final int _UI_INFO_SYNTHESIS =  9;

    /**
     * The information to be sent to an end-user is synthesized from text.
     */
    public static final UIInfoType UI_INFO_SYNTHESIS = new UIInfoType(_UI_INFO_SYNTHESIS);


    /**
     * Method allows class to replace/resolve the object read from the stream before it 
     * is returned to the caller. By implementing this method, a class can directly control
     * the types and instances of its own instances being deserialized.
     *
     * @return the resolved UIInfoType object 
     */
    private Object readResolve() throws java.io.ObjectStreamException {
        return _array[_value];
    }

    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * getValueText method, overrides the getValueText() method in class java.lang.Object
     *
     * @return String  The stringified version of the UIInfoType object
     */
    public String getValueText() {
        switch (_value) {
            case _UI_INFO_ID:
                return "UI_INFO_ID";
            case _UI_INFO_DATA:
                return "UI_INFO_DATA";
            case _UI_INFO_ADDRESS:
                return "UI_INFO_ADDRESS";
            case _UI_INFO_BIN_DATA:
                return "UI_INFO_BIN_DATA";
            case _UI_INFO_UUENCODED:
                return "UI_INFO_UUENCODED";
            case _UI_INFO_MIME:
                return "UI_INFO_MIME";
            case _UI_INFO_WAVE:
                return "UI_INFO_WAVE";
            case _UI_INFO_AU:
                return "UI_INFO_AU";
            case _UI_INFO_VXML:
                return "UI_INFO_VXML";
            case _UI_INFO_SYNTHESIS:
                return "UI_INFO_SYNTHESIS";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 9
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static UIInfoType getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException("value [" + value +" ] out of range");
        }
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof UIInfoType)) {
            return false;
        }
        UIInfoType uIInfoType = (UIInfoType) o; 
        if(!(this.getValue() == uIInfoType.getValue())) {
            return false;
        }
        if (this.hashCode() != uIInfoType.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // UIInfoType

