//Source file: UIManager.java
//Date: June 2006
//User Interaction for 3GPP TS 29.198-05 V6.5.0

package org.csapi.jr.se.ui;

/**
 * This interface represents a UIManager.<BR>
 *
 */
public interface UIManager extends org.csapi.jr.se.Service {

    /**
     * Adds a UIManagerListener which is interested in events generated by the UIManager.
     *
     * @param  uIManagerListener  A reference to the UIManagerListener which is to be added as
     *         a listener.
     */
    void addUIManagerListener(org.csapi.jr.se.ui.UIManagerListener uIManagerListener);

    /**
     * Removes a UIManagerListener which is no longer interested in events generated by the UIManager.
     *
     * @param  uIManagerListener  A reference to the UIManagerListener which is to be removed as
     *         a listener.
     */
    void removeUIManagerListener(org.csapi.jr.se.ui.UIManagerListener uIManagerListener);

    /**
     * Invokes the getNotification() method on the Parlay Gateway.
     */
    org.csapi.jr.se.ui.UIEventCriteriaResult[] getNotification()
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException;

    /**
     * Invokes the disableNotifications() method on the Parlay Gateway.
     */
    void disableNotifications()
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException;

    /**
     * Invokes the createUI() method on the Parlay Gateway and returns a reference to a transient interface.
     */
    org.csapi.jr.se.ui.UI createUI(
           org.csapi.jr.se.Address userAddress)
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException,
       org.csapi.jr.se.InvalidNetworkStateException,
       org.csapi.jr.se.InvalidInterfaceTypeException;

    /**
     * Invokes the createUICall() method on the Parlay Gateway and returns a reference to a transient interface.
     */
    org.csapi.jr.se.ui.UICall createUICall(
           org.csapi.jr.se.ui.UITargetObject uiTargetObject)
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException,
       org.csapi.jr.se.InvalidNetworkStateException,
       org.csapi.jr.se.InvalidInterfaceTypeException;

    /**
     * Creates a Notifications object and returns a reference to the interface used to gain access
     * to it's methods.
     *
     * @return  A reference to the Notifications interface.
     */
    org.csapi.jr.se.ui.Notifications createNotifications();

    /**
     * Creates a Notification object and returns a reference to the interface used to gain access
     * to it's methods.
     *
     * @return  A reference to the Notification interface.
     */
    org.csapi.jr.se.ui.Notification createNotification();

}
