//Source file: UIRecognitionCriteria.java
//Date: June 2006
//User Interaction for 3GPP TS 29.198-05 V6.5.0

package org.csapi.jr.se.ui;

/**
 * Defines the Sequence of Data Elements that specify the additional properties for the collection of information in the form of voice recognition according to the specified grammar.
 * 
 */
public final class UIRecognitionCriteria implements java.io.Serializable {

    private String speakerID;
    private org.csapi.jr.se.ui.UIRecognitionProperty[] properties;
    private String grammar;

    /**
     * Creates a new UIRecognitionCriteria instance.
     */
    public UIRecognitionCriteria () {}

    /**
     * Creates a new UIRecognitionCriteria instance.
     * @param _speakerID   Defines the user identifier associating a user with a speech profile known to the recognition engine, which provides a hint for better quality.
     * @param _properties   Defines the properties set for additional information to the speech recognition engine.
     * @param _grammar   Defines the syntax of the language to be recognized.
     */
    public UIRecognitionCriteria (String _speakerID, org.csapi.jr.se.ui.UIRecognitionProperty[] _properties, String _grammar) {

        this.speakerID = _speakerID;
        this.properties = _properties;
        this.grammar = _grammar;
    }

    /**
     * This method returns a speakerID.
     * 
     * @return a String value
     */
    public String getSpeakerID() {
        return speakerID;
    }

    /**
     * This method returns a properties.
     * 
     * @return a org.csapi.jr.se.ui.UIRecognitionProperty[] value
     */
    public org.csapi.jr.se.ui.UIRecognitionProperty[] getProperties() {
        return properties;
    }

    /**
     * This method returns a grammar.
     * 
     * @return a String value
     */
    public String getGrammar() {
        return grammar;
    }


    /**
     * This method sets a speakerID.
     */ 
    public void setSpeakerID(String speakerID) {
        this.speakerID = speakerID;
    }

    /**
     * This method sets a properties.
     */ 
    public void setProperties(org.csapi.jr.se.ui.UIRecognitionProperty[] properties) {
        this.properties = properties;
    }

    /**
     * This method sets a grammar.
     */ 
    public void setGrammar(String grammar) {
        this.grammar = grammar;
    }


    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof UIRecognitionCriteria)) {
            return false;
        } 
        UIRecognitionCriteria uIRecognitionCriteria = (UIRecognitionCriteria) o;
        if(!(this.speakerID == uIRecognitionCriteria.speakerID))  {
            return false;
        }
        if(!(this.properties == uIRecognitionCriteria.properties))  {
            return false;
        }
        if(!(this.grammar == uIRecognitionCriteria.grammar))  {
            return false;
        }
        if (this.hashCode() != o.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // UIRecognitionCriteria

