//Source file: UIReport.java
//Date: June 2006
//User Interaction for 3GPP TS 29.198-05 V6.5.0

package org.csapi.jr.se.ui;

/**
 * Defines the UI reports if a response was requested.
 *
 */
public final class UIReport implements java.io.Serializable {

    private int _value;
    private static int _size = 9;
    private static UIReport[] _array = new UIReport[_size];

    /**
     * Private constructor used internally to construct static objects 
     */
    private UIReport(int value) {
        _value = value;
        _array[_value] = this;
    }

    /**
     * Undefined report.
     */
    public static final int _UI_REPORT_UNDEFINED =  0;

    /**
     * Undefined report.
     */
    public static final UIReport UI_REPORT_UNDEFINED = new UIReport(_UI_REPORT_UNDEFINED);

    /**
     * Confirmation that the information has been sent.
     */
    public static final int _UI_REPORT_INFO_SENT =  1;

    /**
     * Confirmation that the information has been sent.
     */
    public static final UIReport UI_REPORT_INFO_SENT = new UIReport(_UI_REPORT_INFO_SENT);

    /**
     * Information collected., meeting the specified criteria.
     */
    public static final int _UI_REPORT_INFO_COLLECTED =  2;

    /**
     * Information collected., meeting the specified criteria.
     */
    public static final UIReport UI_REPORT_INFO_COLLECTED = new UIReport(_UI_REPORT_INFO_COLLECTED);

    /**
     * No information collected. The user immediately entered the delimiter character. No valid information has been returned.
     */
    public static final int _UI_REPORT_NO_INPUT =  3;

    /**
     * No information collected. The user immediately entered the delimiter character. No valid information has been returned.
     */
    public static final UIReport UI_REPORT_NO_INPUT = new UIReport(_UI_REPORT_NO_INPUT);

    /**
     * No information collected. The user did not input any response before the input timeout expired.
     */
    public static final int _UI_REPORT_TIMEOUT =  4;

    /**
     * No information collected. The user did not input any response before the input timeout expired.
     */
    public static final UIReport UI_REPORT_TIMEOUT = new UIReport(_UI_REPORT_TIMEOUT);

    /**
     * A message has been stored successfully.
     */
    public static final int _UI_REPORT_MESSAGE_STORED =  5;

    /**
     * A message has been stored successfully.
     */
    public static final UIReport UI_REPORT_MESSAGE_STORED = new UIReport(_UI_REPORT_MESSAGE_STORED);

    /**
     * The message has not been stored successfully.
     */
    public static final int _UI_REPORT_MESSAGE_NOT_STORED =  6;

    /**
     * The message has not been stored successfully.
     */
    public static final UIReport UI_REPORT_MESSAGE_NOT_STORED = new UIReport(_UI_REPORT_MESSAGE_NOT_STORED);

    /**
     * A message has been deleted successfully.
     */
    public static final int _UI_REPORT_MESSAGE_DELETED =  7;

    /**
     * A message has been deleted successfully.
     */
    public static final UIReport UI_REPORT_MESSAGE_DELETED = new UIReport(_UI_REPORT_MESSAGE_DELETED);

    /**
     * A message has not been deleted successfully.
     */
    public static final int _UI_REPORT_MESSAGE_NOT_DELETED =  8;

    /**
     * A message has not been deleted successfully.
     */
    public static final UIReport UI_REPORT_MESSAGE_NOT_DELETED = new UIReport(_UI_REPORT_MESSAGE_NOT_DELETED);


    /**
     * Method allows class to replace/resolve the object read from the stream before it 
     * is returned to the caller. By implementing this method, a class can directly control
     * the types and instances of its own instances being deserialized.
     *
     * @return the resolved UIReport object 
     */
    private Object readResolve() throws java.io.ObjectStreamException {
        return _array[_value];
    }

    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * getValueText method, overrides the getValueText() method in class java.lang.Object
     *
     * @return String  The stringified version of the UIReport object
     */
    public String getValueText() {
        switch (_value) {
            case _UI_REPORT_UNDEFINED:
                return "UI_REPORT_UNDEFINED";
            case _UI_REPORT_INFO_SENT:
                return "UI_REPORT_INFO_SENT";
            case _UI_REPORT_INFO_COLLECTED:
                return "UI_REPORT_INFO_COLLECTED";
            case _UI_REPORT_NO_INPUT:
                return "UI_REPORT_NO_INPUT";
            case _UI_REPORT_TIMEOUT:
                return "UI_REPORT_TIMEOUT";
            case _UI_REPORT_MESSAGE_STORED:
                return "UI_REPORT_MESSAGE_STORED";
            case _UI_REPORT_MESSAGE_NOT_STORED:
                return "UI_REPORT_MESSAGE_NOT_STORED";
            case _UI_REPORT_MESSAGE_DELETED:
                return "UI_REPORT_MESSAGE_DELETED";
            case _UI_REPORT_MESSAGE_NOT_DELETED:
                return "UI_REPORT_MESSAGE_NOT_DELETED";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 8
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static UIReport getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException("value [" + value +" ] out of range");
        }
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof UIReport)) {
            return false;
        }
        UIReport uIReport = (UIReport) o; 
        if(!(this.getValue() == uIReport.getValue())) {
            return false;
        }
        if (this.hashCode() != uIReport.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // UIReport

