//Source file: UISynthesisRate.java
//Date: June 2006
//User Interaction for 3GPP TS 29.198-05 V6.5.0

package org.csapi.jr.se.ui;

/**
 * Defines the rate of the speech.
 *
 */
public final class UISynthesisRate implements java.io.Serializable {

    private int _value;
    private static int _size = 3;
    private static UISynthesisRate[] _array = new UISynthesisRate[_size];

    /**
     * Private constructor used internally to construct static objects 
     */
    private UISynthesisRate(int value) {
        _value = value;
        _array[_value] = this;
    }

    /**
     * Slow speech rate
     */
    public static final int _UI_RATE_SLOW =  0;

    /**
     * Slow speech rate
     */
    public static final UISynthesisRate UI_RATE_SLOW = new UISynthesisRate(_UI_RATE_SLOW);

    /**
     * Average speech rate
     */
    public static final int _UI_RATE_AVERAGE =  1;

    /**
     * Average speech rate
     */
    public static final UISynthesisRate UI_RATE_AVERAGE = new UISynthesisRate(_UI_RATE_AVERAGE);

    /**
     * Fast speech rate
     */
    public static final int _UI_RATE_FAST =  2;

    /**
     * Fast speech rate
     */
    public static final UISynthesisRate UI_RATE_FAST = new UISynthesisRate(_UI_RATE_FAST);


    /**
     * Method allows class to replace/resolve the object read from the stream before it 
     * is returned to the caller. By implementing this method, a class can directly control
     * the types and instances of its own instances being deserialized.
     *
     * @return the resolved UISynthesisRate object 
     */
    private Object readResolve() throws java.io.ObjectStreamException {
        return _array[_value];
    }

    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * getValueText method, overrides the getValueText() method in class java.lang.Object
     *
     * @return String  The stringified version of the UISynthesisRate object
     */
    public String getValueText() {
        switch (_value) {
            case _UI_RATE_SLOW:
                return "UI_RATE_SLOW";
            case _UI_RATE_AVERAGE:
                return "UI_RATE_AVERAGE";
            case _UI_RATE_FAST:
                return "UI_RATE_FAST";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 2
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static UISynthesisRate getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException("value [" + value +" ] out of range");
        }
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof UISynthesisRate)) {
            return false;
        }
        UISynthesisRate uISynthesisRate = (UISynthesisRate) o; 
        if(!(this.getValue() == uISynthesisRate.getValue())) {
            return false;
        }
        if (this.hashCode() != uISynthesisRate.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // UISynthesisRate

