//Source file: UITargetObjectType.java
//Date: June 2006
//User Interaction for 3GPP TS 29.198-05 V6.5.0

package org.csapi.jr.se.ui;

/**
 * Defines the type of object where User Interaction should be performed upon.
 *
 */
public final class UITargetObjectType implements java.io.Serializable {

    private int _value;
    private static int _size = 3;
    private static UITargetObjectType[] _array = new UITargetObjectType[_size];

    /**
     * Private constructor used internally to construct static objects 
     */
    private UITargetObjectType(int value) {
        _value = value;
        _array[_value] = this;
    }

    /**
     * User-interaction will be performed on a complete Call.
     */
    public static final int _UI_TARGET_OBJECT_CALL =  0;

    /**
     * User-interaction will be performed on a complete Call.
     */
    public static final UITargetObjectType UI_TARGET_OBJECT_CALL = new UITargetObjectType(_UI_TARGET_OBJECT_CALL);

    /**
     * User-interaction will be performed on a complete Multi-party Call.
     */
    public static final int _UI_TARGET_OBJECT_MULTI_PARTY_CALL =  1;

    /**
     * User-interaction will be performed on a complete Multi-party Call.
     */
    public static final UITargetObjectType UI_TARGET_OBJECT_MULTI_PARTY_CALL = new UITargetObjectType(_UI_TARGET_OBJECT_MULTI_PARTY_CALL);

    /**
     * User-interaction will be performed on a single Call Leg.
The media of this call leg should be detached at the moment any user interaction is done.
     */
    public static final int _UI_TARGET_OBJECT_CALL_LEG =  2;

    /**
     * User-interaction will be performed on a single Call Leg.
The media of this call leg should be detached at the moment any user interaction is done.
     */
    public static final UITargetObjectType UI_TARGET_OBJECT_CALL_LEG = new UITargetObjectType(_UI_TARGET_OBJECT_CALL_LEG);


    /**
     * Method allows class to replace/resolve the object read from the stream before it 
     * is returned to the caller. By implementing this method, a class can directly control
     * the types and instances of its own instances being deserialized.
     *
     * @return the resolved UITargetObjectType object 
     */
    private Object readResolve() throws java.io.ObjectStreamException {
        return _array[_value];
    }

    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * getValueText method, overrides the getValueText() method in class java.lang.Object
     *
     * @return String  The stringified version of the UITargetObjectType object
     */
    public String getValueText() {
        switch (_value) {
            case _UI_TARGET_OBJECT_CALL:
                return "UI_TARGET_OBJECT_CALL";
            case _UI_TARGET_OBJECT_MULTI_PARTY_CALL:
                return "UI_TARGET_OBJECT_MULTI_PARTY_CALL";
            case _UI_TARGET_OBJECT_CALL_LEG:
                return "UI_TARGET_OBJECT_CALL_LEG";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 2
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static UITargetObjectType getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException("value [" + value +" ] out of range");
        }
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof UITargetObjectType)) {
            return false;
        }
        UITargetObjectType uITargetObjectType = (UITargetObjectType) o; 
        if(!(this.getValue() == uITargetObjectType.getValue())) {
            return false;
        }
        if (this.hashCode() != uITargetObjectType.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // UITargetObjectType

